ElementDataContainer class final

Constructors

ElementDataContainer()

Properties

hashCode int
The hash code for this object.
no setterinherited
lastFrameId int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
get<T extends ElementData>() → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set<T extends ElementData>(T value) → T
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited